children property
A list of child nodes representing the next level in the hierarchy.
Defaults to an empty list if not provided.
Implementation
final List<CascadeNode<T>> children;
A list of child nodes representing the next level in the hierarchy.
Defaults to an empty list if not provided.
final List<CascadeNode<T>> children;